=========
Changelog
=========

Version 1.0.0
=============

- Massive Feature update
- Bug fix

Version 0.1.3
=============

- Improved graphs
- Improved tutorial

Version 0.1.2
=============

- Docs reference fix

Version 0.1.1
=============

- Download data API
- More tests
- Technical indicators

Version 0.0.7
=============

- README link bug fix

Version 0.0.6
=============

- PyPi & readthedocs integration

Version 0.0.5
=============

- Bug fix with conf.py

Version 0.0.4
=============

- Bug fix with requirements.txt

Version 0.0.3
=============

- Proper docs

Version 0.0.2
=============

- Deleted classifiers

Version 0.0.1
=============

- Main backtesting functionality works
- Docs added




